package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````<"$```````!``````````)##````
M````0P```$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````E`````````"4``````````0`````````!````
M!0```````````````````````````````````'"G````````<*<`````````
M0`````````$````&````\+T```````#P_0```````/#]````````F`0`````
M``#`!`````````!``````````@````8`````O@````````#^`````````/X`
M`````````@`````````"````````"``````````$````!````&`"````````
M8`(```````!@`@```````$0`````````1``````````$`````````%#E=&0$
M````Z*````````#HH````````.B@````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/"]````````\/T```````#P_0``
M`````!`"````````$`(````````!`````````"]L:6(V-"]L9"UL:6YU>"UL
M;V]N9V%R8V@M;'`V-&0N<V\N,0`````$````%`````,```!'3E4`Y"2KFI[/
M-<8A5>GC<U@6_17&1CL$````$`````$```!'3E4```````4````3````````
M``````!#````8@``````````````70```!L```!)````(0````````!6````
M`````!8```!#````1@```#X```!<````#P```#0````_```````````````O
M``````````````!1````*@```%<````I````.@```&````!8````5```````
M``````````````````!/````1````$<`````````4@```#T`````````10``
M```````U````7P```!H````5````"P```!X```!0`````````#``````````
M7@```#@````M````'``````````\````0@```$@```!!````"0```$H````Y
M````-@```$P`````````````````````````````````````````````````
M``````````````````````````````<`````````#@``````````````````
M`$T`````````$```````````````````````````````````````````````
M#0``````````````#``````````````````````````C````````````````
M````````````````````$0```"``````````$P```"L```!+````)@```"@`
M````````$@```!T````W````)````$X````[````4P`````````R````)P``
M`$````!;````6@````H````N````%``````````````````````````?````
M80`````````9````60`````````(````````````````````(@```#$```!5
M````,P```!<`````````+``````````````````````````E````&```````
M```1````2@````0````(````(!`0``5`!(`H```$@(8`A(*)``()(`0(B(`0
M0;H``@@`````2@```$T```!0````40````````!9````6@````````!<````
M70````````!>````7P```&$``````````````&[%WQ_.WD<M:W^:?"[%F[8@
M_^0.U634?-EQ6!SB1\8!0OK7AZQ+X\"ZXY)\PN4_+/JA;&"R`8MOF4_#FV>O
MS&9"1=7LB0=PTS-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````````````
M`````````````````````````````P`-`%`?````````````````````````
M`P`.`'A?`````````````````````````P`0`-BA````````````````````
M`````P`4`````0```````````````````````P`6`(`"`0``````````````
M`````````P`7`(@"`0````````````````#[`0``$@``````````````````
M``````"O`0``$@````````````````````````!E`0``$@``````````````
M```````````+`@``$@````````````````````````"R`@``$0``````````
M```````````````!````(``````````````````````````W`@``$@``````
M``````````````````"-`0``$@````````````````````````!)`@``$0``
M``````````````````````"1`@``$@`````````````````````````^`0``
M$@````````````````````````!W`0``$@````````````````````````"V
M`0``$@`````````````````````````3`@``$@``````````````````````
M``!X````$@````````````````````````"5`0``$@``````````````````
M``````#F`0``$@````````````````````````#5````$@``````````````
M``````````"F`0``$@````````````````````````#4`0``$@``````````
M``````````````#%`0``$@````````````````````````"#`@``$@``````
M``````````````````!\`@``$@````````````````````````"B`@``$@``
M```````````````````````P`0``$@````````````````````````"W````
M$0`````````````````````````A`@``$@````````````````````````#^
M````$@`````````````````````````Y`P``$@``````````````````````
M``!4````%@````````````````````````!L`0``$@``````````````````
M``````"*`@``$@````````````````````````!9`0``$@``````````````
M``````````!M`@``$@````````````````````````#L`0``$@``````````
M```````````````"`@``$@`````````````````````````,`0``$@``````
M``````````````````#A`0``$@````````````````````````!0`@``$@``
M``````````````````````!%````$@````````````````````````#,`@``
M$0````````````````````````"'````$@````````````````````````"3
M````$@`````````````````````````E`0``$@``````````````````````
M``#K````$@`````````````````````````O`@``$@``````````````````
M```````W````$@````````````````````````#?````$@``````````````
M``````````!.`0``$@````````````````````````#$````$@``````````
M``````````````"?`0``$@````````````````````````"^`0``$@``````
M```````````````````P`@``$@````````````````````````!G````$@``
M``````````````````````#-`0``$@````````````````````````"H````
M$@````````````````````````!U`@``$@`````````````````````````<
M`0``$@````````````````````````#:````$@``````````````````````
M``"(`0``$@`````````````````````````=````(```````````````````
M``````#;`0``$@````````````````````````"Z`@``$@``````````````
M``````````"H`@``$@````````````````````````!7`@``(@``````````
M``````````````"P`@``$0````````````````````````!F`@``$@``````
M``````````````````!"`P``$@`-``!`````````Z`````````!N`P``$@`-
M`%0W````````<`8```````!$`@``$@`-`%`?````````'`(````````6`P``
M$@`-`.@J````````!`````````#E`P``$@`-`.PJ````````;`(````````C
M!```$@`-`,0]````````/`(```````#1`P``$``7`(@"`0``````````````
M``!5`P``$@`-`%@M````````-`````````![`P``$@`-`.Q7````````I`0`
M``````"&`P``$0`.`'A?````````!`````````"U`P``$``7`+`"`0``````
M``````````#=`P``$@`-`+@I````````*`````````#R`P``$@`-`&PV````
M````Z``````````$!```$@`-`/`S````````;``````````2!```$@`-`%PT
M````````7`````````!B`P``$@`-`(PM````````8`$```````!.`P``$``6
M`(@"`0````````````````"K`P``$0`4`$```0``````"`````````#6`P``
M$@`-`'`A````````8``````````:!```$@`-`'Q7````````<``````````G
M`P``$@`-`$0V````````*`````````"5`P``$@`-`.`I````````"`$`````
M``#'`P``$@`-`)!<````````V`(```````"Z`P``$@`-`.PN````````!`4`
M````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!0
M3%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E
M96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR
M`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!M:V1I
M<@!?7W9F<')I;G1F7V-H:P!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P
M<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?
M;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!O<&5N
M9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T
M:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K
M`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`
M;&0M;&EN=7@M;&]O;F=A<F-H+6QP-C1D+G-O+C$`<&%R7V-U<G)E;G1?97AE
M8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A
M=&$`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?
M=7!D871E`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!M
M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T
M87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A
M<E]E;G9?8VQE86X`<&%R7V1I90!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`1TQ)0D-?,BXS-@````````````````````(``@`"``(``@`!``(`
M`@`"``(``0`"``(``@`!``(``@`!``(``@`"``(``@`"``$``0`"``$``@`!
M``$``@`!``(``@`"``$``@`"``$``P`!``$``0`!``(``0`!``$``0`"``(`
M`@`!``(``0`"``$``@`"``$``@`"``(``@`"``(``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`/@"```0````
M(````+:1E@8```,`.00````````!``$`[@(``!``````````MI&6!@```@`Y
M!````````/#]`````````P````````#$(@```````/C]`````````P``````
M``!L(@```````!```0```````P````````#88````````!@``0```````P``
M``````!`8P```````"```0```````P````````!(8P```````"@``0``````
M`P````````!08P```````#```0```````P````````!88P```````$```0``
M`````P````````!@8P```````&`"`0```````P````````!0'P```````(`"
M`0```````P````````"``@$``````!`"`0```````@````L`````````````
M`!@"`0```````@````P``````````````"`"`0```````@````T`````````
M`````"@"`0```````@````\``````````````#`"`0```````@```!$`````
M`````````#@"`0```````@```!X``````````````$`"`0```````@```"``
M`````````````$@"`0``````"P```"0``````````````%`"`0```````@``
M`"\``````````````%@"`0```````@```#,``````````````&@"`0``````
M`@```#P``````````````'`"`0```````@```$,``````````````'@"`0``
M`````@```$<``````````````%@``0``````!0````<``````````````&``
M`0``````!0````@``````````````&@``0``````!0````D`````````````
M`'```0``````!0````H``````````````'@``0``````!0````X`````````
M`````(```0``````!0```!```````````````(@``0``````!0```!(`````
M`````````)```0``````!0```!,``````````````)@``0``````!0```!0`
M`````````````*```0``````!0```!4``````````````*@``0``````!0``
M`!8``````````````+```0``````!0```!<``````````````+@``0``````
M!0```!@``````````````,```0``````!0```!D``````````````,@``0``
M````!0```!H``````````````-```0``````!0```!L``````````````-@`
M`0``````!0```!P``````````````.```0``````!0```!T`````````````
M`.@``0``````!0```!\``````````````/```0``````!0```"$`````````
M`````/@``0``````!0```"(````````````````!`0``````!0```",`````
M``````````@!`0``````!0```"4``````````````!`!`0``````!0```"8`
M`````````````!@!`0``````!0```"<``````````````"`!`0``````!0``
M`"@``````````````"@!`0``````!0```"D``````````````#`!`0``````
M!0```"H``````````````#@!`0``````!0```"L``````````````$`!`0``
M````!0```"P``````````````$@!`0``````!0```"T``````````````%`!
M`0``````!0```"X``````````````%@!`0``````!0```#``````````````
M`&`!`0``````!0```#$``````````````&@!`0``````!0```#(`````````
M`````'`!`0``````!0```#0``````````````'@!`0``````!0```#4`````
M`````````(`!`0``````!0```#8``````````````(@!`0``````!0```#<`
M`````````````)`!`0``````!0```#@``````````````)@!`0``````!0``
M`#D``````````````*`!`0``````!0```#H``````````````*@!`0``````
M!0```#L``````````````+`!`0``````!0```#T``````````````+@!`0``
M````!0```#X``````````````,`!`0``````!0```#\``````````````,@!
M`0``````!0```$```````````````-`!`0``````!0```$$`````````````
M`-@!`0``````!0```$(``````````````.`!`0``````!0```$0`````````
M`````.@!`0``````!0```$4``````````````/`!`0``````!0```$8`````
M`````````/@!`0``````!0```$<````````````````"`0``````!0```$D`
M`````````````,X!`!RMO1$`S^'1**U1_P+,X=$"K05%`(PAP"C@`0!,SP$`
M'.^AT2CM`0!,``!``\\!`!SO@=$H[0$`3```0`//`0`<[V'1*.T!`$P``$`#
MSP$`'.]!T2CM`0!,``!``\\!`!SO(=$H[0$`3```0`//`0`<[P'1*.T!`$P`
M`$`#SP$`'._AT"CM`0!,``!``\\!`!SOP=`H[0$`3```0`//`0`<[Z'0*.T!
M`$P``$`#SP$`'.^!T"CM`0!,``!``\\!`!SO8=`H[0$`3```0`//`0`<[T'0
M*.T!`$P``$`#SP$`'.\AT"CM`0!,``!``\\!`!SO`=`H[0$`3```0`//`0`<
M[^'/*.T!`$P``$`#SP$`'._!SRCM`0!,``!``\\!`!SOH<\H[0$`3```0`//
M`0`<[X'/*.T!`$P``$`#SP$`'.]ASRCM`0!,``!``\\!`!SO0<\H[0$`3```
M0`//`0`<[R'/*.T!`$P``$`#SP$`'.\!SRCM`0!,``!``\\!`!SOX<XH[0$`
M3```0`//`0`<[\'.*.T!`$P``$`#SP$`'.^ASBCM`0!,``!``\\!`!SO@<XH
M[0$`3```0`//`0`<[V'.*.T!`$P``$`#SP$`'.]!SBCM`0!,``!``\\!`!SO
M(<XH[0$`3```0`//`0`<[P'.*.T!`$P``$`#SP$`'._AS2CM`0!,``!``\\!
M`!SOP<TH[0$`3```0`//`0`<[Z'-*.T!`$P``$`#SP$`'.^!S2CM`0!,``!`
M`\\!`!SO8<TH[0$`3```0`//`0`<[T'-*.T!`$P``$`#SP$`'.\AS2CM`0!,
M``!``\\!`!SO`<TH[0$`3```0`//`0`<[^',*.T!`$P``$`#SP$`'._!S"CM
M`0!,``!``\\!`!SOH<PH[0$`3```0`//`0`<[X',*.T!`$P``$`#SP$`'.]A
MS"CM`0!,``!``\\!`!SO0<PH[0$`3```0`//`0`<[R',*.T!`$P``$`#SP$`
M'.\!S"CM`0!,``!``\\!`!SOX<LH[0$`3```0`//`0`<[\'+*.T!`$P``$`#
MSP$`'.^ARRCM`0!,``!``\\!`!SO@<LH[0$`3```0`//`0`<[V'+*.T!`$P`
M`$`#SP$`'.]!RRCM`0!,``!``\\!`!SO(<LH[0$`3```0`//`0`<[P'+*.T!
M`$P``$`#8X#^`G@@P2GX`0`:86#!*7=`P2EY`,$I>N#`*0Q#R2B,`0`FC0`5
M`&5`P"EF(,`I94#``F8@P`)D<,`";*#`*6UP@"G_3_Y7Y@$`&L9@R2CD`0`:
MQ0`5`(2@R2@`O#]4[`$`&HP!R2B,`0`J@"T!0/<!`!KW0LH"[`$`&HPAR2B-
M"0PX>1P`)*Q)$BHD$X`"A`Q!`(P-@`.L21(I_X?]5VY`P"CL`0`:CP'!*,T!
M`"9L'``DY"+`*8T``">-```:K<',`HT@P"F-```:K>',`HU@P"F/0,`I#02`
M`CD/@`*'`!4`K"4!9)`-@`+.(<`"$8)```P0@`+/`0`FC0U!`(P%@`+O-!PX
MSB'``I'M_U\,@D``Y&+`*(P-00`E```:"``5`"8#%0"E,.4"X#`<./_3_5>`
MF`!`Y&+`*'J0P`+_@_Q7F0`5`(0``!I%`Q4`A*#!`@`X`E2`@`!`Y&+`*/\#
M_%?_?_U7&$/)*&V@P"@,`P`FK*4`7&%@P2AW0,$H>"#!*'K@P"@D`Q4`>0#!
M*&.`P0(@``!,UP$`&O]G_%?W0LH"Y&+`*8!H`$#_A_M7S`$`&HTAR2BM"0PX
M+@``%*VY$`"@&28I_[?^4^1BP"C_L_U7_V?_4^1"P"B`#`!``-`>5/][_U.$
M```:10,5`(3`_P(`F`%4Y$+`*9]@_T,`L!Y4_UO_4PP0@`+_"_]3!`2``O^/
M_5?_Z_I7``!``XD`%0#$`0`:#(#)`@P``!:,`0`#A#`,.&4`P"AF(,`"`P"#
M``<`%0`(`!4`:@`5`,$!`!H,@,@"#```%HP!``,A,`PX(0``3,$!`!H,X,@"
M#```%HP!``,A,`PX(0``3&/`_P)V(,`IQ`$`&G9`P`+,`0`:A"#!`HPAP0*$
M'0!8S`$`&HQAR"B`$0!`=B#`*&-`P`*``0!,=B#`*&-`P`(@``!,Q`$`&LP!
M`!J$(,$"A2'!`J60$0!CP/\"K`Q)`*7\10!V(,`II;`0`'9`P`*E!$D`H!P`
M0,P!`!J,P<DH@!$`0'8@P"AC0,`"@`$`3'8@P"AC0,`"(```3&.`_P)V0,`I
M=R#`*6%@P"EV@,`"UP$`&NPB"BJ`*0!$S`$`&HSAR2B`$0!`S`$`&H0!RBC_
MD_Q7_R__5PP$@`+L(@HI86#`*'9`P"AW(,`H8X#``B```$QCP/\"=B#`*79`
MP`)V(,`H8T#``O\__U-C`/\"8>#`*7?`P"EXH,`I>8#`*7I@P"E[0,`I?"#`
M*7T``">`O`!`S`$`&HQ!R"B=`0`FH*\`0(P``"B:`!4`NP`5`)D`%0`-](`"
M@)T`0(T1`%@L!P`H.0?``I_U_T<Y:Q$`MP,`)N`V`$"X`Q4`'/2``B8#%0!%
M`Q4`Y`(5`/_'^U>`#`!$[&8`.)P]`%@7(\`H&"/``O_>_T=AX,`H>*#`*'F`
MP"AZ8,`H>T#`*'P@P"A]```FY`(5`'?`P"AC`,$"(```3!CW$0`8#TD`.0?`
M`G@#`"7WYA``_\/_4Q<`%0#_N_]3&0`5`/][_U-C0/T"=X#"*=<!`!IX8,(I
M8:#"*>Q"R2B,`0`F92#``I@`%0!L(,(I_R_Z5X`X`$1L&``D[@$`%(T``!2,
MN10`C(%``(T-`%A-`0`4C1T`7`4(@`($`Q4`_]_X5X0$0`(`"`!0!``5`/="
MR2AM(,(H[`(`)JP9`%QAH,(H=X#"*'A@PBACP,("(```3/_[]U=C`/T">*#"
M*=@!`!IAX,(I=\#"*7F`PBEZ8,(I>T#"*0Q#R2B,`0`F;"#"*8`0`$",```H
MEP`5`(`U`$080\DH;2#"*`P#`":L(0%<8>#"*'?`PBAXH,(H>8#"*'I@PBA[
M0,(H8P##`B```$S_N_A7F0`5`)_(_T,D`Q4`_[OW5X"P`$",3``JFDS``HQ)
MOP*`#0!$3`<`*I_A_T.,3``JC$F_`H"A`$#D`A4`_\OW5YL`%0!$`Q4`_[_W
M5V03$`"$"(`"__/V5X<``!I)`Q4`Z`(5`.<`_@(&_+\"!02``IH`%0#_,_=7
M92#``D0#%0#_1_E7#/R_`HP<`%AL&``D[@$`%(T``!2,N10`C(%``(U-`%A$
M`Q4`_P_Y5T0#%0#_9_E7)`,5`/\/]U>?6/]')`,5`/\S]U?D`A4`_VOY5___
M_E-,!P`JC$F_`I]=_T=,"P`JGR7_0_]3_U-$`Q4`_Z/^5_^[_U/_C_978X#^
M`G@@P2G8`0`:=T#!*7D`P2EA8,$I>N#`*7O`P"E\H,`I?8#`*7Y@P"E_0,`I
M#$/)*(P!`":M```HN0`5`&P@P"D,](`"EP`5`*P)`%RY!,`")`,5`/^S]E>;
M`!4`91#``N0"%0#_K_Q7F@`5`(`8`4#_E_97F_``;'T$`"3<`0`:O0]!`.T"
M`"CL`A4`#O2``J"A`4"N$0!8C04`*(P%P`*_]?]'C%T1`(U#R"BZ`0`F9`O`
M`H2P$`#_C_571'<<.(!D`$"<0\@HC0,`)NP"`"CD!L`"KG4,.`_T@`+,`0`I
M@!D`1`"8`%",```HA`3``JP%`"F`B0!`S0$5`,X%P`*/Z?]?#/2``JP!`"FN
M!<`"#``5`"TS`#C-,1`XC`7``K_U_T<80\DH;2#`*`P#`":L%0%<86#!*'=`
MP2AX(,$H>0#!*'K@P"A[P,`H?*#`*'V`P"A^8,`H?T#`*&.`P0(@``!,#``5
M`"TS`#A-,Q`XC`7``K_U_T?_K_]3S0$5`/^'_U/<`0`:C$/(*)\!`";L`P`F
M@*4`0.P#%0`:`!4`C2'`*$X#%0",(<`"6@>``K_Q_T?.#8`"Q`U!`,P!`!J,
M0<H"C0$`)*!%`$0-!(`"C0$`)?]S]%>>`!4`GTC_0UT/00"F`Q4`Y0,5`/\K
M]5>,0\@HG@$`)TP'@`*,#4$`P#,<.'H0@"G_?_Y3A0`5`.0#%0#_0_17C$/(
M*(0!`">>`!4`GP#_0UT/00#_S_]3#``5`/]W_E,$0(`"&@`5`/]__U/_0_17
M8P#_`GB@P"GM__\5V`$`&G?`P"EY@,`I>F#`*6'@P"E[0,`I#$/)*&.T$`"Z
M`!4`+0``%,7__Q6,`0`FI>"_`ZU!@`.ME1``F0`5`(0``!H&_+\#I8T0`(0@
M_@)L"!`G_R_U5Y>`0``7+`!D+@``%.S__Q7.08`#SK$0`.W^OP+,C1``C+40
M`(SA/RB`70!$H%4`1,P!`!J,(<DHA`D,.$8#%0`E`Q4`_W?T5QA#R2AM"!`F
M#`,`)JQ]`%PM```48[00`&'@P"AWP,`H>*#`*'F`P"AZ8,`H>T#`*&,`P0(@
M``!,MP$5`-O__Q4L```4>^._`XQ!@`.,[1``FXT0`.8"%0`%O(`"9`,5`/^S
M]%>?A/]#S`$`&HPAR2B$"0PXYP(5`&8#%0`E`Q4`_W/U5_]__U/_"_-78\#_
M`G<``"=A(,`IUP$`&NPBR2B$"0PX!P$`&L8!`!J%```:YT##`L;`R"BE8/X"
M_Y?T5_<BR2CD"@PX82#`*'<``":(```:"*',`D8``!J%```:"0`5``<!%0#&
M$/<"I>#^`F-`P`+_K_13S`$`&HPAR2B$"0PX!P$`&L8!`!J%```:YT##`L;`
MR"BE8/X"_S?T4V/`_@)XX,`IV`$`&F$@P2EW`,$I><#`*7J@P"D,0\DHC`$`
M)LW__Q5CM!``;!@@)__C\5>W__\53```%/>BOP.,@8`#C-T0`)>-$`")```:
MAP``&B8``!2(`!4`*4'_`N=@_P+&!(`#!02``N0"%0#_(_)7V?__%4P``!0Y
MP[\#C(&``XSE$`"9C1``Y`(5`"8``!0E`Q4`_ROS5Y>`0`#@7@!@Y`:``O^+
M\5>:`!4`@!0`0.8"%0`E`Q4`_U?R5T!?$#@80\DH;1@@)@P#`":L-0!<30``
M%&.T$`!A(,$H1`,5`'<`P2AXX,`H><#`*'J@P"AC0,$"(```3!H`%0#_Q_]3
M_V_Q5__[_E-C@/P"?F#"*=X!`!IW0,,I>"##*7D`PREA8,,I>N#"*7O`PBE\
MH,(I?8#"*7]`PBG,0\DH[?__%6.T$`"W`!4`C0$`)L7__Q4L```4I="]`XQ!
M@@.9`!4`C)40`(0``!J%C1``A,#_`FV($"?_A_=7F``5``6\@`(D`Q4`_]OS
M5X!@`$"$```:A`#``B4#%0#_3_I7)`,5`-Y#R2AMB!`FS`,`)JS%`5PM```4
M8[00`&%@PRAW0,,H>"##*'D`PRAZX,(H>\#"*'R@PBA]@,(H?F#"*']`PBAC
M@,,"(```3.0"%0#_H_)7FP``&F5#P`+_Q_)7EP`5`)^,_T/:__\5+```%%KC
MOP.,08(#C.D0`)J-$`#L`@`HG0``&IP``!J]8\`"G(/``H#I`$``%P!`Y0(5
M``0#%0#_/_%7@+@`0.0"%0#_H_!7C/S_`NRR$`"?`!4`#KR``NP6`&@`)`!0
M@`$`*8S]_P+L#@!8C0$`**[Q_UOD`A4`_V_P5Y\`%0`D`Q4`_V/P5X3\$`"$
M!,`"#/R_`X3Q_FL%!(`"*@,5`*D#%0#H`A4`AP,5`"8``!1$`Q4`_]/O5\7_
M_Q4L```4I>"]`XQ!@@.,E1``A8T0`$0#%0#_T_%7@!P`1&P8`"3N`0`4#0$`
M%(RY%`",@4``C4T`6&5#P`($`!4`_[OQ5Y<`%0"?@/Y#[`(`*)\A_T<`$P!`
M#`,`*HQ)OP*`%0!`EP``&A\$@`+WHO\"_U?_4PP'`"J?P?]#_^O_4P4$@`)$
M`Q4`_]/O5Y^L_T>$```:10,5`(0`P`+_A_A71`,5`/\G\5?_-_Y3___N5V/`
M_P(%O(`"=P``)V$@P"F7`!4`__?N5X`(`$"7!,`"82#`*.0"%0!W```F8T#`
M`O_K\%-C0/\">4#`*=D!`!IAH,`I=X#`*7A@P"DL0\DHC`$`)NW__Q5CM!``
M;`@0)X#H`$",```HF``5`(#=`$#_"^]7A@3``BP``!27`!4`A@D!:,W__Q4L
M```4K>&_`XQ!@`.,M1``C8T0``4#%0"D`14`__?N5^S^_P*,L!``#KR``HP4
M`&@`&`!0@`$`*8S]_P*$#0!8C0$`**[Q_UO7__\5+```%/?BOP.,08`#C-T0
M`)>-$``%O(`"Y`(5`/\;[E>`5`!`Y(H`:,3__Q4L```4A."_`XQ!@`.,D1``
MA(T0`/\'\%<Y0\DH;0@0)BP#`":L;0!<+0``%&.T$`!AH,`H=X#`*'A@P"AY
M0,`H8\#``B```$PY0\DH;0@0)BP#`":L/0!<+0``%&.T$`!AH,`H=X#`*'A@
MP"AY0,`HA```&H2@_P)CP,`"_Y_O4X```"G_>_]3!``5`/^/_U/_:^U78X#^
M`G@@P2G8`0`:=T#!*7D`P2EZX,`I86#!*7O`P"E\H,`I?8#`*7Y@P"D,0\DH
MC`$`)ID``!IW$,`";"#`*3FCP`+:`0`:Y0(5`"0#%0#_H_-7@$0`0$Q#R"AM
M!``DCP$`)JT-00#LM1``CB'`*.XU'#C?U?]#C4'`*(PAP`*-`0`GO_7_1^4"
M%0`D`Q4`_V/S5Y_$_T>9```:.>/``MH!`!KE`A4`)`,5`/]'\U>`1`!`3$/(
M*&T$`"2/`0`FK0U!`.RU$`".(<`H[C4<.-_5_T.-0<`HC"'``HT!`">_]?]'
MY0(5`"0#%0#_!_-7G\3_1YD``!HY`\$"V@$`&N4"%0`D`Q4`_^OR5X!$`$!,
M0\@H;00`)(\!`":M#4$`[+40`(XAP"CN-1PXW]7_0XU!P"B,(<`"C0$`)[_U
M_T?E`A4`)`,5`/^K\E>?Q/]'>0``&CE#P0*Z`0`:Y0(5`"0#%0#_C_)7@$0`
M0$Q#R"AM!``DCP$`)JT-00#LM1``CB'`*.XU'#C?U?]#C4'`*(PAP`*-`0`G
MO_7_1^4"%0`D`Q4`_T_R5Y_$_T=Y```:.F/!`KL!`!KE`A4`1`,5`/\S\E>`
M1`!`;$/(*&T$`"2/`0`FK0U!`.RU$`".(<`H[C4<.-_5_T.-0<`HC"'``HT!
M`">_]?]'Y0(5`$0#%0#_\_%7G\3_1WH``!I:H\$"NP$`&N4"%0!$`Q4`_]?Q
M5X!$`$!L0\@H;00`)(\!`":M#4$`[+40`(XAP"CN-1PXW]7_0XU!P"B,(<`"
MC0$`)[_U_T?E`A4`1`,5`/^7\5>?Q/]'>@``&EO#_P*\`0`:Y0(5`&0#%0#_
M>_%7@$0`0(Q#R"AM!``DCP$`)JT-00#LM1``CB'`*.XU'#C?U?]#C4'`*(PA
MP`*-`0`GO_7_1^4"%0!D`Q4`_SOQ5Y_$_T=[```:?./!`KT!`!KE`A4`A`,5
M`/\?\5>`1`!`K$/(*&T$`"2/`0`FK0U!`.RU$`".(<`H[C4<.-_5_T.-0<`H
MC"'``HT!`">_]?]'Y0(5`(0#%0#_W_!7G\3_1WP``!J=(\("O@$`&N4"%0"D
M`Q4`_\/P5X!$`$#,0\@H;00`)(\!`":M#4$`[+40`(XAP"CN-1PXW]7_0XU!
MP"B,(<`"C0$`)[_U_T?E`A4`I`,5`/^#\%>?Q/]'?0``&KUCP@*^`0`:Y0(5
M`*0#%0#_9_!7@$0`0,Q#R"AM!``DCP$`)JT-00#LM1``CB'`*.XU'#C?U?]#
MC4'`*(PAP`*-`0`GO_7_1^4"%0"D`Q4`_R?P5Y_$_T=]```:O0/``KX!`!KE
M`A4`I`,5`/\+\%>`1`!`S$/(*&T$`"2/`0`FK0U!`.RU$`".(<`H[C4<.-_5
M_T.-0<`HC"'``HT!`">_]?]'Y0(5`*0#%0#_R^]7G\3_1V0``!KE`A4`A*#"
M`O^W[U>%`!4`@`P`0(0CP@+_D_)79```&N4"%0"$`,,"_Y?O5X4`%0"`$`!`
M9```&H1@PP+_;_)79```&N4"%0"$H,,"_W/O5X4`%0"`5`!`1,/_`O]/\E<8
M0\DH;2#`*`P#`":L80!<86#!*'=`P2AX(,$H>N#`*'O`P"A\H,`H?8#`*'Y@
MP"@D8\$">0#!*&4``!JE0,0"8X#!`O\'\E-D```:Y0(5`(3@PP+_"^]7A0`5
M`)^D_T-DX\$"_^?Q5_^;_U/_9^A78X#_`G=`P"FW`0`:86#`*>Q"R2B,`0`F
M9```&F40P`*$X,$";"#`*?_'[E>`-`!`A```*(`L`$"$0/\"!)`2`/="R2AM
M(,`H[`(`)JP=`%QA8,`H=T#`*&.`P`(@``!,!``5`/_?_U/_^^=78X#^`JT!
M`!JL`0`:9:#`*6;`P"EGX,`I86#`*6@`P2EI(,$I:D#!*6M@P2FM0<DHC*'(
M**T!`":&`!4`A`$`)F>@P`(%!(`";2#`*6<``"?_Y^A7!/R#`O\_ZE=CP/X"
M>J#`*;H!`!IW`,$I>.#`*6$@P2EYP,`I>X#`*7Q@P"E]0,`I3$/)*(P!`"8-
M_O\58[00``T"`!2M(8`#!@B``@4`%0"L#1PXF``5`/\KYU>7_/\"[?Y)`*W!
M10#LMA``C`'/`(RU$0#WLA$`X/H`8/W]_Q4,`@`4O<._`XQ!@`.,]1``&?R_
M`IV-$``;'(`"O`$`&@8`%0#E`A4`!`,5`/_7YE>9U`!8!@(`%,8@@`.E`Q4`
M!`,5`/]/Z%>$@$``F:P`6&27`&R,X/\"K+,0`)V)`&B/`\`"``P`4(S]_P*=
M>0!HC@$`)NT!`";-\?]?[?W_%0X"`!2MP;\#SD&``\ZU$`#-C1``C+41`(3=
M$``,`@`4C"&``UI#R2B-#0PX3`,`)JQA`%P-`@`48[00`&$@P2AW`,$H>.#`
M*'G`P"AZH,`H>X#`*'Q@P"A]0,`H8T#!`B```$P,_O\5][(0`.PV_U\$_+\"
M_ZO_4V0``!J$H,0"_R_^5V0``!J$8,0"_R/^5_\3YE=CP/\"82#`*?]WZ%>$
M@$``_^_F5X`(`$"$```F82#`*&-`P`(@``!,8P#_`GB@P"FX`0`:>8#`*7I@
MP"EAX,`I=\#`*7M`P"D,0\DHC`$`)GH``!J9`!4`91#``D3CQ`)L(,`I_S?L
M5X`0`$",```HEP`5`(`]`$080\DH;2#`*`P#`"8E`Q4`K(4`7&'@P"AWP,`H
M>*#`*'F`P"A[0,`H1./$`GI@P"AC`,$"_]ON4R0#%0#_V^57FP`5`.0"%0#_
MS^579),0`(0(P`+_`^57:0``&F<``!KJ`A4`!02``BE!P`(H`Q4`YX#``@;\
MOP*7`!4`_SOE5QA#R2AM(,`H#`,`)N4"%0"LA?];_P/E5V.`^0)YX,4IK`$`
M&KD!`!J,`<`">`#&*7K`Q2E[H,4I86#&*79`QBEW(,8I?(#%*7U@Q2E^0,4I
M?R#%*2U#R2BS`0`FDD'`*)%AP"B0@<`HCZ'`*([!P"B-X<`H;```&HQ!Q0)L
M@,`I;```&HRA_P)LH,`I;```&HQAQ0)X<,`">P``&FS@P"EL```:F@`5`(R!
MQ0(%`Q4`9,/_`G/@Q"E@P,`I<D#!*7%@P2EP@,$I;Z#!*6[`P2EMX,$I;`#!
M*6`@P2G_Q^I7@!``0(P``"B7`!4`@#$$1/^7YE>$@$``_P_E5X`,`D"7```F
MX`8"0.0"%0#_B^17A`1!`(0$P`+_O^-7Z`(`*)T`%0"<`!4``#4`0'X``!K>
MP\4""(%G`*0#%0#'`Q4`!OR_`@4$@`+_[^-7Z`8`*+T+P`+W!L`"']W_1V0`
M`!I]0,$"A&##`@`0`%"D(\`HO2/``H`T`$`%`Q4`_R?J5Y<`%0"?Z/]#C```
M*)_A_T/_`^M7G]C_0^0"%0#_F^57EP`5`(`P`$1]@,`"MP,`)N`F`$#L`@`H
M@$D!0.0"%0#_T^I7@"0!1+<CP"B](\`"_^;_1^0"%0#_O^-7GP`5`(0#%0#_
ML^-7_Q,0`/\3D`+D`Q4`_^/B5WX``!IJ```:9P``&HL#%0!*X<4"R6/``N@"
M%0#G`,8"!OR_`@4$@`*=`!4`_Q/C5P4`AP*D`Q4`_S?C5PS\OP*,%`!<_\OB
M5XD``"0,1(`"+*T"7&4`P@*D`Q4`_Y/D5Y<`%0"`'`!$;)``).X!`!2-```4
MC+D4`(R!0`"-_0!8K`$`&HRAR"A'`P`FA`$`)F8``!JH`Q4`QD#'`@4$@`+_
M3^-7'``5`#E#R2AMX,0H+`,`)JS-`UQA8,8H=D#&*'<@QBAX`,8H>>#%*'K`
MQ2A[H,4H?6#%*'Y`Q2A_(,4HA`,5`'R`Q2AC@,8"(```3.0"%0#_2^17EP`5
M`+TCP`*?M/Y#_]O^4Q<`%0#_T_Y39.#`*'S@P`*`)`!`!0,5`/^+Z%>`#`!`
MC```*(`Q`$2$(\`HG"/``I_D_T<$-(`"_Y_A5W<``!J=`!4`G``5`/<BQ0((
M3($"_]_]4__CXU>7`!4`G\S_0_\WXE>$!$$`A`3``O^O_5-\F``D_Q/D5XR`
M0`",__Y?;)``)`T`AP*,_4<#C>W^7^0#%0#_0^%7G``5`&0``!H%`Q4`A*#(
M`O_[YU>%`!4`@+@!0$0#`";_^^]7E@`5`("H`4#$`A4`_\_A5Y^`0``,#(`"
MGS4`9.3S_P)E```:I<#(`L22$`#_/^)7@!P`1`P0@`+L2P)8_^^_`LU^`#@,
MO(`"K#D"6'H``!H%`Q4`1./!`O^/YU>`6`%`C```*(!1`4`-P(`"C4D!6&4`
M`!JE0,0"1./!`O]7ZE?_>^!7>```&F<``!H+H\P"B@`5`,ECP`*H`Q4`YX#)
M`@;\OP(%!(`"A`,5`'H``!K_R^!7'_R_`A9$@`(8H\P"WF/``EK#R0(`0`!0
M_W_@5XP``"2610!<_R/@5_<&@`**`!4`>```)^L"%0#)`Q4`J`,5`$<#%0`&
M_+\"!02``H0#%0#_=^!7!0"'`H0#%0#_F^!7G[C_6Z0#%0#_S^)79,/_`H4#
M%0#_J^E7A`,5`/]'^E?_L_U3K`$`&HRAR"A'`P`FA`$`)F8``!JH`Q4`QD#&
M`@4$@`+_T^!7_X?]4_\7^E<Y0\DH;>#$*"P#`":L30%<86#&*'9`QBAX`,8H
M>>#%*'K`Q2A[H,4H?(#%*'U@Q2A^0,4H?R#%*.0"%0!W(,8H8X#&`O_3X5-6
M`P`F_UO^4P4`%0#$`A4`_T_?5Y@`%0"?K/Y#__OW5Y\`%0"`H/YCA=C_`@8`
M%0`$`Q4`_UO?5W8`Q`(&&(`"Q0(5``0#%0#_U^!7#!B``HS$`%QM``$DC(*&
M%(P!C`.L9?Y?S1)`*HP``!2,(94#K%7^7P8`%0#E._\"!`,5`/\/WU=W(,0"
M!J"``N4"%0`$`Q4`_XO@5PR@@`*,>`!<:P``&F<``!IKH<P"Z@(5`,ECP`*H
M`Q4`YT#)`@;\OP(%!(`"A`,5`&#`!"G_`]]7_Y_^4UHCP"A?R_U#1`,5`/]/
MWU<,#(`"A+G];X3P_P)E```:I>#(`D23$`#_P]]7UA(3`$23$P#6$A4`_Y?]
M4_^?WE=D```:A`#)`O^?]E=C`/\">8#`*;D!`!IWP,`I>F#`*6'@P"EXH,`I
M>T#`*2Q#R2B,`0`FMP$`&GH0P`)L(,`I["+)*)@)##AD```:10,5``S#`BJ$
M8,$"#,<"*?_+Y%>`$`!`C0``*`S$@`*LG0%8_\?P5^PBR2B8"0PX90``&@0#
M%0`'#(`"!@2``J4@R@+_:]]7F``5`(`T`$",0,`H[2+)**0)##B%`0`F9@``
M&L9`R@+_Q]Y7#$/`*(4!`":L#``DC%G6`(!M`43L(LDHA`D,.&4``!H'#(`"
M!@2``J5@R@+_%]]7FP`5`(`P`$!D```:10,5`(0`P`+_*^17A@`5`(`0`4!L
M0\`H[2+)**0)##B%`0`F_V/>5[@!`!H80\H"["+)*)L)##AE```:!@2``J6`
MR@)D`Q4`___>5V8``!J%`!4`QN#*`F0#%0#_*]Y7]R+)*.P*##AD```:10,5
M`(#%`BF$P/\"_[OC5P1#P"F7`!4`@'``0`4`AP+D`A4`_V?=5XT$@`(,!(`"
MC2D`;`Q$@`*,(`!8#"/`*(<`%0!D```:A0$`)N8"%0"$H,L"_Y?>5SE#R2AM
M(,`H+`,`)JR!`%QAX,`H=\#`*'B@P"AY@,`H>F#`*'M`P"AC`,$"(```3`0C
MP"C_L_=7!$/`*9<`%0"?A/]'9```&H0`RP+_1]Y7C`0`*)]Q_D/_8_Y3N`$`
M&AA#R@(-(\`H;$/`**4!`":$`0`F_S/H5__W_E/L(LDHA`D,./]/WE?_C_Y3
M_U?<5V-`_P)W@,`IEP$`&GA@P"EAH,`I>4#`*>Q"R2B,`0`FF``5`$0``!IE
M$,`"A.#!`FP@P"G_J^)7@"``0(P``"B`&0!`#<"``HT1`%@`#P!`#`,`*(`M
M`$3W0LDH;2#`*.P"`":L@0!<8:#`*'>`P"AX8,`H>4#`*&/`P`(@``!,!`,5
M`/\+[5<%O(`"F0`5`/_3VU>`"`!`F03``B0#%0#_T]U710``&@80@`*EX,4"
M_W/>5Y^D_T?W0LDH;2#`*.P"`":L(0!<8:#`*'>`P"AY0,`H!`,5`'A@P"AC
MP,`"_W_C4_]OVU=C0/4"B@$`&F&@RBEW@,HI>&#**4Q!R2B,`0`F;B#``N4!
M`!1L(,HID>#``H;@P0+2`14`I0"\`Q3^`10P`@`F+0(`)#$BP`(/@D4`#*)%
M`/-A00`0XD4`C)44`(Q!%0"M,0``<`+?`.\A00"MP4P`C$$5`._1%`"M`=\`
MC#T5`$T"`"=,(L`I4D+``M&P_U]FP,$H9>#!*&T`PBAT8,`H<X#`*'*@P"AQ
MP,`H<.#`*&@`P2C)`<@"``@`4.@!%0#/`<$HS`$`)J<!%0#.(<`"[+$5`(R9
M%0",T14`C05!`(Q]10"M,14`K0'?`,WAP2FF`!4`=`(5`.4`%0!3`A4`,@(5
M`!$"%0`0`14`R;'_7Y(``"9F(,`HCD#`*(]@P"B0(,`HD8#`*.T$M12M9:8#
M3&Y%`%0600"4,A4`QK00`-.]%0`%"D4`#'I!`,;$$`"4`M\`C!45`'/"%`"4
MFA``9D#`*(4!WP!SOA4`E,X0`-.5%0"4`M\`<\H4`,:T$`#&O!``AQ9!`(EN
M10!SNA4`<YH0`.8D%0!+"D4`2'I!`'.:$`!F8,`H""T5`(RA%0",T10`QK00
M`',"WP#&N!``C)45`&D600!K;D4`AWI!`(R9$`"4"D4`9H#`*.=0%0`T+14`
MC-$0`!2=%0#&M!``"`'?`)3.%`",`=\`Q900`)2B%0")%4$`BVU%`&9Z00"4
MEA``<PI%`&6@P"C&3!4`,RT5`)3.$`#SF!4`E`+?`.<`WP!SLA0`I;00`*6@
M$`")%D$`BVY%`'.>%0"(>4$`C`E%``@Q%0!SEA``+"T5`'.R$`!E`M\`<\#`
M*,R@%0",T10`Q@#?`'.V$`!SGA``J11!`*ML10",F14`C,T0`#,M%0",S1``
MAWI!`)0*10#G4!4`E`'?`&S@P"@3G14`<Y84``@!WP",M1``C)D0`(D600"+
M;D4`<Z(5`'.R$``L+14`<[(0`*9X00"E"$4`QA05`&4"WP!S`,$H[)@5`(S1
M%`#G`-\`<[80`'.B$`"I%$$`JVQ%`(R=%0",S1``,RT5`(S-$`"(>D$`E`I%
M``A1%0"4`=\`;"#!*-.@%0!SEA0`Q@#?`(RU$`",G1``B19!`(MN10!SFA4`
M<[(0`"PM%0!SLA``IWA!`*4(10#G%!4`90+?`'-`P2@,G14`C-$4``@!WP!S
MMA``<YH0`*D400"K;$4`C*$5`(S-$``S+14`C,T0`(9Z00"4"D4`QE`5`)0!
MWP!L8,$H\Y@5`'.6%`#G`-\`C+40`(RA$`")%D$`BVY%`'.>%0!SLA``+"T5
M`'.R$`"H>$$`I0A%``@5%0!E`M\`<X#!*,R@%0",T10`Q@#?`'.V$`!SGA``
MJ11!`*ML10",F14`C,T0`#,M%0",S1``AWI!`)0*10#G4!4`E`'?`&R@P2@3
MG14`<Y84``@!WP",M1``C)D0`(D600"+;D4`<Z(5`'.R$``L+14`<[(0`*9X
M00"E"$4`QA05`&4"WP!SP,$H[)@5`(S1%`#G`-\`<[80`'.B$`"I%$$`JVQ%
M`(R=%0",S1``,RT5`(S-$`"(>D$`E`I%``A1%0"4`=\`;.#!*-.@%0!SEA0`
MQ@#?`(RU$`",G1``B19!`(MN10!SFA4`<[(0`"PM%0!SLA``IWA!`*4(10#G
M%!4`90+?`',`PB@,G14`C-$4``@!WP!SMA``<YH0`*D400"K;$4`C*$5`(S-
M$``S+14`C,T0`(9Z00"4"D4`QE`5`)0!WP!L(,(H\Y@5`'.6%`#G`-\`C+40
M`(RA$`");D4`B!9!`'.>%0"K>$$`<[(0`*4(10`,)14`:$#"*&45%0!SLA``
MS)05`',"WP`(M1``Q@#?`(S1%``'G1``:6Y%`&@600",F14`C)T0``<E%0!I
M8,(HB'I!`)0*10`(414`C)T0`(P!WP"TH!4`*;40`(MM10"E`-\`E,X4`(<5
M00`FF1``E)85`.<L%0"4FA``YP#?`&9Z00!S"D4`E)X0`,9,%0!K@,(HB0+?
M`!.9%0!SLA0`"`'?`"<500`W;44`:[40`&VB%0#S7!4`AWE!`(P)10#G,!4`
M9940`,R<%0"ME1``<P+?`(S1%0!TH,(HI<T0`,VSW12MA:X#JP#?`'=M10"4
MMA``<Q5!`)2B$`!S7A4`C`'?`(S1$`!S`M\`D\T0`"AY00!LP,(H*0E%``@E
M%0#TH!4`:0+?`#=M10",M1``Q@#?`(66%0`T%4$`C)D0`*4`WP"47A4`C)40
M`)0"WP"4T1``9GE!`&S@PBAK"44`QBP5``69%0"+`M\`=VU%`(RU$`#G`-\`
MI<P5`',500",G1``I0#?`'->%0",E1``<P+?`)/-$``G>4$`;`##*"D)10#G
M)!4`Q9P5`&D"WP`W;44`C+40``@!WP"ET!4`-!5!`(RA$`"E`-\`E%X5`(R5
M$`"4`M\`E-$0`&5Y00!L(,,H:PE%`*4L%0"(`M\`ZY05`-<`WP",M1``9LT5
M``MM10`3%4$`C-T0`,8`WP!S+A4`C)D0`',"WP"3S1``)GE!`&Q`PR@I"44`
MQB05`*N8%0!I`M\`]P#?`(RU$`!GT14`*VU%`#0500",W1``YP#?`)0N%0",
MG1``E`+?`)31$``'>4$`;&##*`@)10#G(!4`RYP5`(@"WP"W`-\`C+40`&7-
M%0`+;44`$Q5!`(S=$`"E`-\`<RX5`(R5$`!S`M\`D\T0`"5Y00!L@,,H*0E%
M`*4D%0#KE!4`:0+?`-<`WP",M1``9M$5`"MM10`T%4$`C-T0`,8`WP"4+A4`
MC)D0`)0"WP"4T1``!GE!`&R@PR@("44`QB`5`*N8%0"(`M\`]P#?`(RU$`!G
MS14`"VU%`!,500",W1``YP#?`',N%0",G1``<P+?`)/-$``G>4$`;,##*"D)
M10#G)!4`RYP5`&D"WP"W`-\`C+40`&71%0`K;44`-!5!`(S=$`"E`-\`E"X5
M`(R5$`"4`M\`E-$0``5Y00!LX,,H"`E%`*4@%0#KE!4`B`+?`-<`WP",M1``
M9LT5``MM10`3%4$`C-T0`,8`WP!S+A4`C)D0`',"WP"3S1``)GE!`&P`Q"@I
M"44`QB05`*N8%0!I`M\`]P#?`(RU$`!GT14`*VU%`#0500",W1``YP#?`)0N
M%0",G1``E`+?`)31$``'>4$`;"#$*`@)10#G(!4`RYP5`(@"WP"W`-\`C+40
M`&7-%0`+;44`$Q5!`(S=$`"E`-\`<RX5`(R5$`!S`M\`D\T0`"5Y00!L0,0H
M*0E%`*4D%0#KE!4`:0+?`-<`WP",M1``9M$5`"MM10`T%4$`C-T0`,8`WP"4
M+A4`C)D0`)0"WP"4T1``!GE!`&Q@Q"@("44`QB`5`*N8%0"(`M\`]P#?`(RU
M$`!GS14`"VU%`!,500",W1``YP#?`',N%0",G1``<P+?`)/-$``G>4$`;(#$
M*"D)10#G)!4`RYP5`&D"WP"W`-\`C+40`&71%0`K;44`-!5!`(S=$`"E`-\`
ME"X5`(R5$`"4`M\`E-$0``5Y00!LH,0H"`E%`*4@%0#KE!4`B`+?`-<`WP",
MM1``9LT5``MM10`3%4$`C-T0`,8`WP!S+A4`C)D0`',"WP"3S1``)GE!`&S`
MQ"@I"44`QB05`&L"WP"IF!4`=VU%`(RU$`#G`-\`*=$5`'0500",G1``*0'?
M`)1>%0",I1``E`+?`)31$``'>4$`;.#$*`@)10#G(!4`R9P5`(@"WP",M1``
MI0#?`#/-%0`7;44`C)40`',"WP`%%4$`C,T0`+-<%0",S1``:7E!`',`Q2AK
M"44`*2T5`.ND%0"%`=\`<[80`,8`WP!MT14`<YH0`+0400"F;$4`K0'?``QY
M00`("44`C"$5`'.V$`!H(,4HC1H5`'0W'A64<K,#%```%H8!WP!SMA``+3$5
M`',"WP`KF10`K944``C1$`#G`-\`")T0`'=N10"M+14`IWA!`&L600"E"$4`
MYQ05`*VA$`!E714`K940`*@!WP!M0,4HC!T5`.68%``I`=\`C,T4`*W1$`"M
MI1``C!45``EM10`%%4$`:WI!`(RU$`!S"D4`K205`&E@Q2AS314`90+?`(RU
M$`#M3!4`C`'?`.N4%`"MH10`*=$0`"F9$`"7;44`K2T5``9Y00"+%4$`"`E%
M`,8@%0"MI1``:%T5`*VA$`"H`=\`;8#%*',:%0#)E!0`K=$0`'.R%`#G`-\`
M<R85`*>=$``)%4$`"VU%`(UY00","44`K3$5`&R>$``S+14`::#%**<!WP",
MS1``TS05`(P!WP#+G!0`<Z(4`"G1$``IE1``EVU%`',N%0`%>4$`BQ5!``@)
M10"E(!4`<Z80`&A=%0!SHA``:`+?`'/`Q2BM%14`J9P4`'/2$`"ML10`Q@#?
M`*TE%0!FFA``"15!``MM10"3>4$`C`E%`',R%0"LF1``+2T5`&G@Q2AF`M\`
MC+40`*U,%0",`=\`JY@4`*VA%``IT1``*9T0`)=M10"M+14`!WE!`(L500`(
M"44`YR`5`*VE$`!H714`K:$0`*@!WP!M`,8H<QX5`.F8%`"MT1``<[(4`*4`
MWP!S)A4`I940``D500`+;44`C7E!`(P)10"M,14`;)80`#,M%0!I(,8HI0'?
M`(S-$`#S-!4`C`'?`.N4%`!SHA0`*=$0`"F9$`"7;44`<RX5``9Y00"+%4$`
M"`E%`,8@%0!SIA``:%T5`'.B$`!H`M\`<T#&**T9%0#)E!0`<](0`*VQ%`#G
M`-\`K245`&>>$``)%4$`"VU%`)-Y00","44`<S(5`*R=$``M+14`:6#&*&<"
MWP",M1``S4P5`(P!WP#+G!0`K:$4`"G1$``IE1``EVU%`*TM%0`%>4$`BQ5!
M``@)10"E(!4`K:40`&A=%0"MH1``J`'?`&V`QBAS%A4`J9P4`*W1$`!SLA0`
MQ@#?`',F%0"FF1``"15!``MM10"->4$`C`E%`*TQ%0!LFA``,RT5`&F@QBBF
M`=\`C,T0`+,T%0",`=\`JY@4`'.B%``IT1``*9T0`)=M10!S+A4`!WE!`(L5
M00`("44`YR`5`'.F$`!H714`<Z(0`&@"WP!SP,8HK1T5`.F8%`!STA``K;$4
M`*4`WP"M)14`9980``D500`+;44`DWE!`(P)10!S,A4`K)40`"TM%0!IX,8H
M90+?`(RU$`#M3!4`C`'?`.N4%`"MH10`*=$0`"F9$`"7;44`K2T5``9Y00"+
M%4$`"`E%`,8@%0"MI1``:%T5`*VA$`"I`=\`;0#'*',:%0#(E!0`K=$0`'.R
M%`#G`-\`<R(5`*>=$``H%4$`*VU%`(UY00","44`K3$5`&R>$``3+14`:R#'
M**<!WP",S1``TS05`(P!WP#(G!0`<Z84`&O1$`!KE1``EQ5!`)AM10`E"44`
M<R(5`"AY00`(%14`<ZX0`.5B%0!SEA``Q0#?`&9`QRBM(14`<P+?``F=%`#&
MT!``K;$4`,64$`"M)14`9A9!`&EN10"ME1``BWE!`,4D%0","44`9F#'*&LQ
M%0"LE1``C`'?`&D!WP`%+14`&*44`)=M10"ES!0`QM`0`(T500#&G!``K5T5
M`*5@%0"EF!``9WI!`*T!WP!F"D4`$P'?`&B`QRCF&!4`I[00`.4`WP!M&14`
MUZ04`*ML10"ML10`"-$0`+0400`(S1``K5T5`),N%0"MH1``<P+?`*W-$`"(
M>4$`:Z#'*(P)10"3Q905"#$5`'-:AP,3```6M`'?`,R@%0"7;D4`C)T5`&O-
M$`"'%D$`:Z40`(P!WP#I7!4`C*T0`"D!WP"G>$$`I0A%`.<4%0"%I1``:<#'
M**L`WP`,G14`*<T0`'=M10",M14`Q@#?`&T500`FF1``K5T5`(P!WP",F1``
MK0'?`(9Z00"4"D4`QE`5`)2U$`!LX,<HB0+?`.V8%0`W;44`C,T0``@!WP"E
ME14`+15!`(RA$`"E`-\`K5T5`(R5$`"M`=\`C;40`&5Y00!L`,@H:PE%`*4L
M%0"H`=\`RY05`/<`WP",S1``9]$5``MM10`4%4$`C-T0`.<`WP"4+A4`C)T0
M`)0"WP"4T1``)WE!`&P@R"@I"44`YR05`*N<%0")`M\`UP#?`(S-$`!FM14`
M*VU%`"T500",W1``Q@#?`*TM%0",F1``K0'?`(VU$``&>4$`;$#(*`@)10#&
M(!4`ZY@5`*@!WP"W`-\`C,T0`&71%0`+;44`%!5!`(S=$`"E`-\`E"X5`(R5
M$`"4`M\`E-$0`"5Y00!L8,@H*0E%`*4D%0#+E!4`B0+?`/<`WP",S1``9[45
M`"MM10`M%4$`C-T0`.<`WP"M+14`C)T0`*T!WP"-M1``!WE!`&R`R"@("44`
MYR`5`*N<%0"H`=\`UP#?`(S-$`!FT14`"VU%`!0500",W1``Q@#?`)0N%0",
MF1``E`+?`)31$``F>4$`;*#(*"D)10#&)!4`ZY@5`(D"WP"W`-\`C,T0`&6U
M%0`K;44`+15!`(S=$`"E`-\`K2T5`(R5$`"M`=\`C;40``5Y00!LP,@H"`E%
M`*4@%0#+E!4`J`'?`/<`WP",S1``9]$5``MM10`4%4$`C-T0`.<`WP"4+A4`
MC)T0`)0"WP"4T1``)WE!`&S@R"@I"44`YR05`*N<%0")`M\`UP#?`(S-$`!F
MM14`*VU%`"T500",W1``Q@#?`*TM%0",F1``K0'?`(VU$``&>4$`;`#)*`@)
M10#&(!4`ZY@5`*@!WP"W`-\`C,T0`&71%0`+;44`%!5!`(S=$`"E`-\`E"X5
M`(R5$`"4`M\`E-$0`"5Y00!L(,DH*0E%`*4D%0#+E!4`B0+?`/<`WP",S1``
M9[45`"MM10`M%4$`C-T0`.<`WP"M+14`C)T0`*T!WP"-M1``!WE!`&Q`R2@(
M"44`YR`5`*N<%0"H`=\`UP#?`(S-$`!FT14`"VU%`!0500",W1``Q@#?`)0N
M%0",F1``E`+?`)31$``F>4$`;&#)*"D)10#&)!4`ZY@5`(D"WP"W`-\`C,T0
M`&6U%0`K;44`+15!`(S=$`"E`-\`K2T5`(R5$`"M`=\`C;40``5Y00!L@,DH
M"`E%`*4@%0"K`=\`R)05`/<`WP",S1``!]$5`&AM10!T%4$`C-T0`.<`WP"4
M(A4`C)T0`)0"WP"4T1``*'E!`&R@R2@I"44`""45`*>@%0")`M\`UP#?`(S-
M$`#FM!4`)VU%`"T500",W1``Q@#?`*T=%0",F1``K0'?`(:U$`!G>4$`;<#)
M*&L)10#G+!4`#)T5`,L`WP"4T14`=VU%`*W-$`"E`-\`;!5!`*V5$`",714`
MA0+?`*V5$`",`=\`I;$0`#1Y00!LX,DH*0E%`)0F%0#MT!4`J0#?`(S-$``(
M`=\`K9D5`(RA$`"M`=\`*!5!`#=M10",M1``#5T5`(RU$`!M`,HH9GE!`&L)
M10#&+!4`K<T0`).:%0",`=\`K<D0`.<`WP!SEA4`K9T0`',"WP"%%4$`AVU%
M`#)Y00`I"44`K<T0`%(F%0"S'!4`D,$0`,:\$`"MS1``3KH0`(S&$`"M`=\`
M#P+?`(P!WP#.`=\`T`#?`(T``">,@,`ICR#`*8Y`P"F08,`I2D')*&T@RBA,
M`0`FK!D`7&&@RBAW@,HH>&#**&/`R@(@``!,_]O$5V/`_P($`(("82#`*?^+
MQ%=-BLX4K06,`XT``"=-F]\5K26N`PT``!:-(,`IK74Q%:WYLP,-```6C4#`
M*:UD(!2MV9$#C6#`*<VEAQ6MP8<##0``%HV`P"F`H,`I@,#`*8#@@2EA(,`H
M8T#``B```$QC@/T"=R#"*7K`P2E[H,$I?(#!*6%@PBEV0,(I>`#"*7G@P2E]
M8,$I?D#!*7\@P2F-H,`HCL#`*)H`%0#,-"T`C`'?`(VU$@"$>``DSK40`,UT
M10"MN1``3*/`*4W#P"G7`!4`O``5`%OCP`*`V`-$#/R``I<I!&3X`K\"%YM$
M`.P&@`*,`=\`C!E!`(RS$`!LH,`I>L#`*7?@@"EX\(`IB2\`*HP[`"J-/P`J
MCD,`*H]'`"J02P`JD4\`*I)3`"J35P`JE%L`*H$C`"J+)P`JBBL`*H@S`"J$
M-P`JE@<`*I\+`"J>#P`JG1,`*IH7`"J9&P`JF!\`*FD(`"EL#``I;1``*6X4
M`"EO&``I<!P`*7$@`"ER)``I<R@`*70L`"F%7P`JAF,`*H=G`"J,;P`JC7,`
M*HYW`"J/>P`JD'\`*I&#`"J2AP`JDXL`*I2/`"J7:P`J93``*68T`"F%DP`J
MAI<`*F<X`"F'FP`J;$``*6U$`"EN2``I;TP`*7!0`"EQ5``I<E@`*7-<`"ET
M8``I960`*69H`"EG;``I=SP`*9>?`"J,HP`JC:<`*HZK`"J/KP`JD;<`*I*[
M`"J3OP`JE,,`*H7'`"J&RP`JD+,`*H?3`"IW<``I;'0`*9?/`"IM>``I;GP`
M*6^``"EQB``I<HP`*9'K`"J2YP`J<Y``*724`"F3XP`JE-\`*F68`"EFG``I
MA=L`*H;7`"IPA``ID.\`*HS_`"J/\P`JCO<`*HW[`"J)`P`J9#<`*60,`"II
M`P`I:0@`*F0[`"ED$``J82,`*6LG`"ED/P`I9!0`*FHK`"EI+P`I9$,`*608
M`"IH,P`I=@<`*61'`"ED'``J?PL`*7X/`"ED2P`I9"``*GT3`"EZ%P`I>1L`
M*7@?`"ED3P`I9"0`*FA<`"J<`\$"9%,`*60H`"IHBP`I:&``*F17`"ED+``J
M9%L`*60P`"ID7P`I9#0`*F1C`"ED.``J9&<`*60\`"ID:P`I9$``*F1O`"ED
M1``J9',`*61(`"ID=P`I9$P`*F1[`"ED4``J9'\`*614`"ID@P`I9%@`*F2'
M`"EDP,`H:(\`*6AD`"IGTP`I=\\`*6B3`"EH:``J:)<`*6AL`"IHFP`I:'``
M*FB?`"EH=``J:*,`*6AX`"IHIP`I:'P`*FBK`"EH@``J:*\`*6B$`"IHLP`I
M:(@`*FBW`"EHC``J:+L`*6B0`"IHOP`I:)0`*FC#`"EHF``J:,<`*6B<`"IH
MRP`I9M<`*6S_`"EEVP`I=-\`*7/C`"ERYP`I<>L`*7#O`"EO\P`I;O<`*6W[
M`"G_)^57;*#`*(S#_%]W.``D#`"_`G@\`"3W,AP`>L#`*/=B$`!EH,`HY@(5
M`&0#%0#__\!75^.!*6%@PBAV0,(H=R#"*'@`PBAYX,$H>L#!*'N@P2A\@,$H
M?6#!*'Y`P2A_(,$H8X#"`B```$P8`($"&!,1``R#0`#,,!(`&+,3`,PP$P`8
M,Q4`&8-``"8#%0!DDQ``_YO`5TQ[`"0-`($"C&$0`(Z!0`!,XX$IS8W_7T0#
M%0#W8A$`G.<0`/]KY%?_V_M3?*#`*?]?_U-C0/\">B#`*;J@P"AW@,`I>&#`
M*4P/10"-_4`#>4#`*7L``">,_4`#8:#`*;G@P`*M!8`"#P"^`KO`P"BN@4``
M+S,0.`S@@`*W`!4`F``5`(Z1`60,`($"C#41``\0@`(MNQ``CUT";`X(@`*.
M00)L@#4"1.0"%0#_X^-7X.+`*2`CP"D@0\`I(&/`*2"#P"D@H\`I(,/`*6UC
M10`,`!4`K`&'`&U#10"L(8\`;2-%`*Q!EP!L8Y\`36-%`*R!IP!-0T4`K*&O
M`$TC10"LP;<`3.._`.S"P2GD`A4`_W_C5^P"`";D`A4`C&%%``P#`"GL`@`F
MC$%%``P'`"GL`@`FC"%%``P+`"GL`@`F#`\`*>PBP"B,844`#!,`*>PBP"B,
M044`#!<`*>PBP"B,(44`#!L`*>PBP"@,'P`I[$+`*(QA10`,(P`I[$+`*(Q!
M10`,)P`I[$+`*(PA10`,*P`I[$+`*`PO`"GL8L`HC&%%``PS`"GL8L`HC$%%
M``PW`"GL8L`HC"%%``P[`"GL8L`H##\`*>R"P"B,844`#$,`*>R"P"B,044`
M#$<`*>R"P"B,(44`#$L`*>R"P"@,3P`I8:#`*'>`P"AX8,`H>4#`*'H@P"A[
M```F8\#``O]WP%,,X(`"C#41``^`@`(MNQ``CY$`;`Y`@`*.;0!L#B"``HY-
M`&P.$(`"CBT`;`X(@`*.$0!LGX7^0Z`!`"G_?_Y3H`%`*8SY_P*M"<`"GVW^
M0__K_U.@`0`EC/'_`@X(@`*M$<`"CM'_:__;_U.@`0`GC.'_`@X0@`*M(<`"
MCK'_:__7_U.@`0`GH"'`*8S!_P(.((`"K4'``HZ-_VO_T_]3(#L<.*`AP"F@
M0<`IH&'`*8R!_P(.0(`"K8'``HYA_VO_Q_]3H`$`*?_/_5.@`4`IC/G_`JT)
MP`*?O?U#_^O_4R`[&#B,\?\"#@B``JT1P`*.H?UK_]O_4VP!`!J'`<HHK/__
M&X`1_T\!``(``````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`
M````97AE```````O<')O8R\E:2\E<P``````+@````````!005)?5$5-4```
M````````4$%27U!23T=.04U%`````#H`````````+P`````````E<R5S)7,`
M`%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!015),
M24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.
M`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%27T=,
M3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````````4$%2
M7U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M```````````Q`````````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```
M````3$1?3$E"4D%265]0051(`%-94U1%30``+W1M<`````!54T52`````%53
M15).04U%```````````E,#)X`````'!A<BT`````)7,E<R5S)7,`````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*````````4$%42`````!P87)L`````"YP87(`````<VAO
M<G0@<F5A9````````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````
M)7,E<W1E;7`M)74M)74E<P``````````&`````````!P97)L`````#``````
M````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@``````````+64````````M+0```````%1-4$1)4@``5$5-4$1)4@!4
M14U0`````%1-4```````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I
M+F,``````````$-!0TA%```!&P,[[````!P```!H?O__;`4``(B`__\$`0``
M]('__Q@!``#D@O__5`$``'2#__^``0``X(3__[@!```LA___``(``&2(__\\
M`@``T(C__UP"``#XB/__<`(```"*__^H`@``!(K__[P"``!PC/__#`,``*2,
M__\L`P``!([__W`#```(D___M`,``'23___<`P``T)/___0#``!<E?__.`0`
M`(25__]4!```;);__XP$``#<G/__^`0``!B?__\P!0```*#__Z`%``"4MO__
MS`4```2W___L!0``J+O__S@&``"`OO__<`8````````0``````````%Z4@`!
M?`$!&PT#`!`````8````?'___V``````!P$`.````"P```#4@/__\`````!$
M#D!@@0*7!)@&F0B:"IL,G`Z=$`)\"L%$V$391-I$VT3<1-U(UT0.`$0+*```
M`&@```"(@?__D`````!$#K`!1)<$3)@&@0(":`K!1-=$V$0.`$0+```T````
ME````.R!__]L`0```$0.P`%$F`98@0*7!)D(F@J;#'`*P4371-A$V43:1-M$
M#@!$"P```$0```#,````((/__TP"````1`Y@1)@&:)<$F0B!`IH*FPR<#IT0
MGA*?%`,,`0K!1-=$V$391-I$VT3<1-U$WD3?1`X`1`L``#@````4`0``)(7_
M_S@!````1`Y`2)@&8`[`()<$F0B:"H$"FPP"F`H.0$3!1-=$V$391-I$VT0.
M`$0+`!P```!0`0``((;__VP`````1`X02)<$@0)TP4379`X`$````'`!``!L
MAO__*``````````T````A`$``("&__\(`0```$0.4$28!F0.T$"!`I<$F0B:
M"@*P"@Y01,%(UT381-E$VD0.`$0+`!````"\`0``4(?__P0`````````3```
M`-`!``!`A___;`(```!$#N`!1)X2=`[@(9<$F`:9"($"F@J;#)P.G1"?%`)T
M"@[@`43!1-=$V$391-I$VT3<1-U$WD3?1`X`1`L````<````(`(``%R)__\T
M`````$0.$$R7!($"5,%(UT0.`$````!``@``<(G__V`!````1`XP1)D(8`ZP
M(($"EP28!@+4"@XP1,%$UT381-E$#@!$"U@*#C!$P4371-A$V4P.`$0+0```
M`(0"``",BO__!`4```!$#F!$F`9DEP29")H*@0*;#)P.G1">$@-\!`K!1-=$
MV$3:1-M$W$3=1-Y(V4P.`$0+```D````R`(``$R/__]L`````$0.($27!$B!
M`@)$"L%$UT0.`$0+````%````/`"``"0C___7`````!$#F!8@1(`0`````@#
M``#4C___C`$```!$#E!$F@IP#M"`!)<$F`:!`ID(FPR<#IT0`OP*#E!$P437
M1-A$V43:1-M$W$3=1`X`1`L8````3`,``!R1__\H`````$0.$$2!`EC!1`X`
M-````&@#```HD?__Z`````!$#D!$F`98F0B:"H$"EP2;#`)("L%$UT381-E$
MVTC:1`X`1`L```!H````H`,``-B1__]P!@```$0.H`-(F0IPF`B:#)L.@0*6
M!)<&G!"=$IX4GQ8#8`(*P4361-=$V$391-I$VT3=1-Y$WTC<1`X`1`L#3`(*
MP4361-A$V43:1-M$W$3=1-Y$WTC71`X`1`L````T````#`0``-R7__\\`@``
M`$0.0$29"%B7!)H*@0*8!IL,`Z`!"L%$UT381-E$VD3;1`X`1`L``#@```!$
M!```X)G__^@`````1`XP1)<$4)@&@0*9"`)4"L%$UT381-E$#@!$"P),"L%$
MUT392-A$#@!$"S````"`!```]'C__QP"````1`Y@1)@&5($"EP29")H*`V`!
M"L%$UT381-I(V40.`$0+```H````M`0``%B:__^4%@```$0.L`50@0*7!)@&
M`VP6"L%$UT381`X`1`L``!P```#@!```P+#__W``````1`X02($"`ES!1`X`
M````2``````%```0L?__I`0```!$#J`!;)<&F@R;#IP0@0*6!)@(F0J=$IX4
MGQ8#Y`,*P4361-=$V$391-I$VT3<1-U$WD3?1`X`1`L``#0```!,!0``:+7_
M_]@"````1`XP1)H*9)<$F`:9")L,@0(#F`$*P4371-A$V43:1-M$#@!$"P``
M$````(0%```(N/__$```````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````Q"(```````!L(@````````$`````
M````W@(````````!`````````.X"`````````0````````#X`@```````!D`
M````````\/T````````;``````````@`````````&@````````#X_0``````
M`!P`````````"``````````$`````````*@"````````]?[_;P````!(!0``
M``````4`````````4`\````````&`````````"`&````````"@````````!$
M!`````````L`````````&``````````5`````````````````````P``````
M``!(``$```````(`````````$`4````````4``````````<`````````%P``
M``````#`%@````````<`````````F!0````````(`````````"@"````````
M"0`````````8`````````!X`````````&`````````#[__]O``````$```@`
M````_O__;P````!8%````````/___V\``````@````````#P__]O`````)03
M````````^?__;P`````*````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````"E!!4BYP;0H``````````-A@````````0&,```````!(
M8P```````%!C````````6&,``````````````````&!C````````________
M__\``````````-`;````````T!L```````#0&P```````-`;````````T!L`
M``````#0&P```````-`;````````T!L```````#0&P```````-`;````````
MT!L```````#0&P```````-`;````````T!L```````#0&P```````-`;````
M````T!L```````#0&P```````-`;````````T!L```````#0&P```````-`;
M````````T!L```````#0&P```````-`;````````T!L```````#0&P``````
M`-`;````````T!L```````#0&P```````-`;````````T!L```````#0&P``
M`````-`;````````T!L```````#0&P```````-`;````````T!L```````#0
M&P```````-`;````````T!L```````#0&P```````-`;````````T!L`````
M``#0&P```````-`;````````T!L```````#0&P```````-`;````````T!L`
M``````#0&P```````-`;````````T!L```````#0&P````````#^````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````!0'P``````````
M`````````````````````````````(`"`0``````1T-#.B`H1&5B:6%N(#$S
M+C(N,"TY*2`Q,RXR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB
M=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L
M82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N9V]T`"YS
M9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````X`@```````#@"````````)0``````````````````
M``$````````````````````3````!P````(`````````8`(```````!@`@``
M`````"0````````````````````$````````````````````)@````<````"
M`````````(0"````````A`(````````@````````````````````!```````
M`````````````#@````%`````@````````"H`@```````*@"````````G`(`
M```````&``````````@`````````!``````````T````]O__;P(`````````
M2`4```````!(!0```````-0`````````!@`````````(````````````````
M````/@````L````"`````````"`&````````(`8````````P"0````````<`
M```'````"``````````8`````````$8````#`````@````````!0#P``````
M`%`/````````1`0```````````````````$```````````````````!.````
M____;P(`````````E!,```````"4$P```````,0`````````!@`````````"
M``````````(`````````6P```/[__V\"`````````%@4````````6!0`````
M``!```````````<````"````"````````````````````&H````$`````@``
M``````"8%````````)@4````````*`(````````&``````````@`````````
M&`````````!T````!````$(`````````P!8```````#`%@```````!`%````
M````!@```!4````(`````````!@`````````>0````$````&`````````-`;
M````````T!L```````"``P``````````````````$``````````0````````
M`'X````!````!@````````!0'P```````%`?````````*$``````````````
M``````@```````````````````"$`````0````(`````````>%\```````!X
M7P```````&]!```````````````````(````````````````````C`````$`
M```"`````````.B@````````Z*````````#L````````````````````!```
M`````````````````)H````!`````@````````#8H0```````-BA````````
MF`4```````````````````@```````````````````"D````#@````,`````
M````\/T```````#PO0````````@````````````````````(``````````@`
M````````L`````\````#`````````/C]````````^+T````````(````````
M````````````"``````````(`````````+P````&`````P``````````_@``
M``````"^``````````(````````'``````````@`````````$`````````#%
M`````0````,````````````!````````P````````$@`````````````````
M```(````````````````````RP````$````#`````````$@``0``````2,``
M```````X`@``````````````````"``````````(`````````-`````!````
M`P````````"``@$``````(#"````````"`````````````````````@`````
M``````````````#7````"`````,`````````B`(!``````"(P@```````"@`
M```````````````````(````````````````````W`````$````P````````
M````````````B,(````````>`````````````````````0`````````!````
M``````$````#`````````````````````````*;"````````Y0``````````
7``````````$`````````````````````
